@@ -27,13 +27,17 @@ describe 'watcher::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
+          { :client_package_name => 'python3-watcherclient' }
+        when 'RedHat'
+          if facts[:operatingsystem] == 'Fedora'
             { :client_package_name => 'python3-watcherclient' }
           else
-            { :client_package_name => 'python-watcherclient' }
+            if facts[:operatingsystemmajrelease] > '7'
+              { :client_package_name => 'python3-watcherclient' }
+            else
+              { :client_package_name => 'python-watcherclient' }
+            end
           end
-        when 'RedHat'
-          { :client_package_name => 'python-watcherclient' }
         end
       end
 
